import numpy as np
import pandas as pd
import scipy as sp
import matplotlib.pyplot as plt
from plg_filters import plg_lowpass

# load some data
p0 = pd.read_csv("P0_signals.csv")

# plot a signal
f1,ax1 = plt.subplots(figsize=(15,3))
ax1.plot(p0.cp3_pre, label="raw data")
ax1.set_xlabel('SAMPLES (5000 Hz)')
ax1.set_ylabel('CP3')
ax1.set_title('P0 pre-learning')
ax1.legend()
f1.tight_layout()
f1.show()

# compute spectrum of the signal and plot it
f,p = sp.signal.welch(p0.cp3_pre, fs=5000, nperseg=1000)
f2,ax2 = plt.subplots()
ax2.plot(f,p)
ax2.set_xlim([0,1000])
ax2.grid(True)
ax2.set_xlabel('FREQUENCY (Hz)')
ax2.set_ylabel('POWER')
ax2.set_title('P0 CP3 PRE')
f2.show()

# try a lowpass filter
try_cutoff = 300
yf = plg_lowpass(p0.cp3_pre, samprate=5000, cutoff=try_cutoff)

# plot it
f3,ax3 = plt.subplots(figsize=(15,3))
ax3.plot(p0.cp3_pre, alpha=0.5, label="raw data")
ax3.plot(yf, label=f"filtered at {try_cutoff} Hz")
ax3.set_xlabel('SAMPLES (5000 Hz)')
ax3.set_ylabel('CP3')
ax3.set_title('P0 pre-learning')
ax3.legend()
f3.tight_layout()
f3.show()


